@@ -16,8 +16,8 @@ def gpu(config):
 def list(config):
     """List GPUs."""
     data = [
-        ["ID", "NAME", "ABBRV", "PROVIDER", "AVAILABLE", "CREDITS/HR"],
-        ["-" * 80, "-" * 80, "-" * 80, "-" * 80, "-" * 80, "-" * 80],
+        ["ID", "NAME", "ABBRV", "CREDITS/HR MIN", "CREDITS/HR MAX"],
+        ["-" * 80, "-" * 80, "-" * 80, "-" * 80, "-" * 80],
     ]
 
     gpus = config.trainml.run(config.trainml.client.gpu_types.list())
@@ -28,14 +28,13 @@ def list(config):
                 gpu.id,
                 gpu.name,
                 gpu.abbrv,
-                gpu.provider,
-                f"{gpu.available}",
-                f"{gpu.credits_per_hour:.2f}",
+                f"{gpu.credits_per_hour_min:.2f}",
+                f"{gpu.credits_per_hour_max:.2f}",
             ]
         )
     for row in data:
         click.echo(
-            "{: >36.34} {: >16.14} {: >10.8} {: >10.8} {: >11.9} {: >12.10}"
+            "{: >36.34} {: >16.14} {: >10.8} {: >16.14} {: >16.14}"
             "".format(*row),
             file=config.stdout,
         )
