@@ -56,7 +56,7 @@ def create(config):
             "v100",
             "a100",
             "a6000",
-            "q4000",
+            "cpu",
         ],
         case_sensitive=False,
     ),
@@ -329,7 +329,7 @@ def notebook(
             "v100",
             "a100",
             "a6000",
-            "q4000",
+            "cpu",
         ],
         case_sensitive=False,
     ),
@@ -627,7 +627,7 @@ def training(
             "v100",
             "a100",
             "a6000",
-            "q4000",
+            "cpu",
         ],
         case_sensitive=False,
     ),
@@ -947,7 +947,7 @@ def from_json(config, attach, connect, file):
             "v100",
             "a100",
             "a6000",
-            "q4000",
+            "cpu",
         ],
         case_sensitive=False,
     ),
