@@ -68,7 +68,8 @@ class Jobs(object):
         type,
         gpu_type=None,
         gpu_types=[],
-        gpu_count=1,
+        gpu_count=None,
+        cpu_count=None,
         disk_size=10,
         max_price=10,
         worker_commands=[],
@@ -83,11 +84,16 @@ class Jobs(object):
             datasets = _clean_datasets_selection(data.get("datasets"))
             data["datasets"] = datasets
 
-        resources = dict(
-            gpu_count=gpu_count,
-            disk_size=disk_size,
-            max_price=max_price,
-        )
+        resources = {
+            k: v
+            for k, v in dict(
+                gpu_count=gpu_count,
+                disk_size=disk_size,
+                max_price=max_price,
+                cpu_count=cpu_count,
+            ).items()
+            if v is not None
+        }
 
         if len(gpu_types):
             resources["gpu_types"] = gpu_types
@@ -110,7 +116,8 @@ class Jobs(object):
             model=model,
             endpoint=endpoint,
             source_job_uuid=kwargs.get("source_job_uuid"),
-            project_uuid=self.trainml.active_project,
+            project_uuid=kwargs.get("project_uuid")
+            or self.trainml.active_project,
         )
         payload = {
             k: v
@@ -148,6 +155,7 @@ class Job:
         self._type = self._job.get("type")
         self._workers = self._job.get("workers")
         self._credits = self._job.get("credits")
+        self._project_uuid = self._job.get("project_uuid")
 
     @property
     def dict(self) -> dict:
@@ -204,24 +212,34 @@ class Job:
             "model",
             "data",
             "environment",
+            "endpoint",
             "workers",
         ]
         resources_keys = [
             "gpu_count",
-            "gpu_type_id",
+            "gpu_types",
             "disk_size",
             "max_price",
             "preemptible",
         ]
-        model_keys = ["git_uri", "model_uuid"]
+        model_keys = ["source_type", "source_uri", "project_uuid"]
         data_keys = [
             "datasets",
             "input_type",
             "input_uri",
+            "input_options",
             "output_type",
             "output_uri",
+            "output_options",
         ]
-        environment_keys = ["type", "env", "worker_key_types"]
+        environment_keys = [
+            "type",
+            "env",
+            "custom_image",
+            "worker_key_types",
+            "packages",
+        ]
+        endpoint_keys = ["routes", "start_command"]
         create_json = dict()
         for k, v in self.dict.items():
             if k in root_keys:
@@ -249,6 +267,12 @@ class Job:
                         if k2 in environment_keys:
                             environment[k2] = v2
                     create_json["environment"] = environment
+                elif k == "endpoint":
+                    endpoint = dict()
+                    for k2, v2 in v.items():
+                        if k2 in endpoint_keys:
+                            endpoint[k2] = v2
+                    create_json["endpoint"] = endpoint
                 elif k == "workers":
                     workers = []
                     for worker in v:
@@ -260,22 +284,34 @@ class Job:
 
     async def start(self):
         await self.trainml._query(
-            f"/job/{self._id}", "PATCH", None, dict(command="start")
+            f"/job/{self._id}",
+            "PATCH",
+            dict(project_uuid=self._project_uuid),
+            dict(command="start"),
         )
 
     async def stop(self):
         await self.trainml._query(
-            f"/job/{self._id}", "PATCH", None, dict(command="stop")
+            f"/job/{self._id}",
+            "PATCH",
+            dict(project_uuid=self._project_uuid),
+            dict(command="stop"),
         )
 
     async def get_worker_log_url(self, job_worker_uuid):
         resp = await self.trainml._query(
-            f"/job/{self._id}/worker/{job_worker_uuid}/logs", "GET"
+            f"/job/{self._id}/worker/{job_worker_uuid}/logs",
+            "GET",
+            dict(project_uuid=self._project_uuid),
         )
         return resp
 
     async def get_connection_utility_url(self):
-        resp = await self.trainml._query(f"/job/{self._id}/download", "GET")
+        resp = await self.trainml._query(
+            f"/job/{self._id}/download",
+            "GET",
+            dict(project_uuid=self._project_uuid),
+        )
         return resp
 
     def get_connection_details(self):
@@ -348,11 +384,15 @@ class Job:
 
     async def remove(self, force=False):
         await self.trainml._query(
-            f"/job/{self._id}", "DELETE", dict(force=force)
+            f"/job/{self._id}",
+            "DELETE",
+            dict(project_uuid=self._project_uuid, force=force),
         )
 
     async def refresh(self):
-        resp = await self.trainml._query(f"/job/{self.id}", "GET")
+        resp = await self.trainml._query(
+            f"/job/{self.id}", "GET", dict(project_uuid=self._project_uuid)
+        )
         self.__init__(self.trainml, **resp)
         return self
 
@@ -395,7 +435,10 @@ class Job:
         await self.refresh()
         if self.status not in ["finished", "failed"]:
             await self.trainml._ws_subscribe(
-                "job", self.id, self._get_msg_handler(msg_handler)
+                "job",
+                self._project_uuid,
+                self.id,
+                self._get_msg_handler(msg_handler),
             )
 
     async def copy(self, name, **kwargs):
@@ -408,10 +451,13 @@ class Job:
         job = await self.trainml.jobs.create(
             name,
             type=kwargs.get("type") or self.type,
-            gpu_type=kwargs.get("gpu_type")
-            or self._job.get("resources").get("gpu_type_id"),
+            gpu_type=kwargs.get("gpu_type"),
+            gpu_types=kwargs.get("gpu_types")
+            or self._job.get("resources").get("gpu_types"),
             gpu_count=kwargs.get("gpu_count")
             or self._job.get("resources").get("gpu_count"),
+            cpu_count=kwargs.get("cpu_count")
+            or self._job.get("resources").get("cpu_count"),
             disk_size=kwargs.get("disk_size")
             or self._job.get("resources").get("disk_size"),
             max_price=kwargs.get("max_price")
